@@ -7,12 +7,13 @@ def handle_categories(result):
     Returns:
         categories (list): List of list of categories. 
     '''
-    categories=[]
+    categories={}
     
     for r in result:
         if r and isinstance(r[0], dict):
                 categories_temp = r[0].get('categories')
-                
+                link_temp = r[0].get('link').split("/")[-2].replace("-", " ").title()
+
                 if isinstance(categories_temp, list):
                     cat_temp = []
                     for item in categories_temp:
@@ -22,10 +23,9 @@ def handle_categories(result):
                 else:
                     cat_temp = ['']
 
-                categories += list(set(cat_temp))
+                cat_temp = list(set(filter(lambda category: category != '', cat_temp)))
+                categories.update({link_temp: cat_temp})
         else:
-            categories += ['No Category']
+            categories.update({'No product': 'No Category'})
     
-    categories = list(filter(lambda category: category != '', categories))
-
     return categories
\ No newline at end of file
